@@ -19,7 +19,7 @@
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
-/* $Id: klflatexsymbols.cpp 997 2017-01-15 09:55:24Z phfaist $ */
+/* $Id$ */
 
 #include <stdio.h>
 
@@ -737,7 +737,13 @@ KLFLatexSymbols::KLFLatexSymbols(QWidget *parent, const KLFBackend::klfSettings&
 #else
 	    parent /* 0 */
 #endif
-	    , /*Qt::Tool*/ Qt::Window /*0*/)
+	    ,
+#if defined(KLF_WS_MAC)
+            Qt::Tool /* to forbid windows from tabbing together */
+#else
+            /*Qt::Tool*/ Qt::Window /*0*/
+#endif
+      )
 {
   KLF_DEBUG_TIME_BLOCK(KLF_FUNC_NAME) ;
   Q_UNUSED(parent) ;
