@@ -19,11 +19,13 @@
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
-/* $Id: klflibdbengine.cpp 603 2011-02-26 23:14:55Z phfaist $ */
+/* $Id$ */
 
 #include <QDebug>
 #include <QApplication>  // qApp
 #include <QString>
+#include <QUrl>
+#include <QUrlQuery>
 #include <QBuffer>
 #include <QFile>
 #include <QByteArray>
@@ -88,10 +90,12 @@
 static QByteArray image_data(const QImage& img, const char *format)
 {
   QByteArray data;
-  QBuffer buf(&data);
-  buf.open(QIODevice::WriteOnly);
-  img.save(&buf, format);
-  buf.close();
+  {
+    QBuffer buf(&data);
+    buf.open(QIODevice::WriteOnly);
+    img.save(&buf, format);
+    buf.close();
+  }
   return data;
 }
 
@@ -101,6 +105,7 @@ static QByteArray metatype_to_data(const T& object)
   QByteArray data;
   {
     QDataStream stream(&data, QIODevice::WriteOnly);
+    stream.setVersion(QDataStream::Qt_4_4) ;
     stream << object;
     // force close of buffer in destroying stream
   }
@@ -112,6 +117,7 @@ static T metatype_from_data(const QByteArray& data)
 {
   T object;
   QDataStream stream(data);
+  stream.setVersion(QDataStream::Qt_4_4) ;
   stream >> object;
   return object;
 }
@@ -145,19 +151,22 @@ KLFLibDBEngine * KLFLibDBEngine::openUrl(const QUrl& givenurl, QObject *parent)
   bool accessshared = false;
 
   QUrl url = givenurl;
+  QUrlQuery urlq(url);
 
-  if (url.hasQueryItem("klfDefaultSubResource")) {
-    QString defaultsubres = url.queryItemValue("klfDefaultSubResource");
+  if (urlq.hasQueryItem("klfDefaultSubResource")) {
+    QString defaultsubres = urlq.queryItemValue("klfDefaultSubResource");
     // force lower-case default sub-resource
-    url.removeAllQueryItems("klfDefaultSubResource");
-    url.addQueryItem("klfDefaultSubResource", defaultsubres.toLower());
+    urlq.removeAllQueryItems("klfDefaultSubResource");
+    urlq.addQueryItem("klfDefaultSubResource", defaultsubres.toLower());
   }
+  url.setQuery(urlq);
 
   QSqlDatabase db;
   if (url.scheme() == "klf+sqlite") {
     QUrl dburl = url;
-    dburl.removeAllQueryItems("klfDefaultSubResource");
-    dburl.removeAllQueryItems("klfReadOnly");
+    urlq.removeAllQueryItems("klfDefaultSubResource");
+    urlq.removeAllQueryItems("klfReadOnly");
+    dburl.setQuery(urlq);
     accessshared = false;
     QString dburlstr = dburl.toString();
     QString path = klfUrlLocalFilePath(dburl);
@@ -232,10 +241,13 @@ KLFLibDBEngine * KLFLibDBEngine::createSqlite(const QString& fileName, const QSt
   if (subrestitle.isEmpty())
     subrestitle = subresname;
 
-  url.addQueryItem("klfDefaultSubResource", subresname);
+  QUrlQuery urlq(url);
+  urlq.addQueryItem("klfDefaultSubResource", subresname);
+  url.setQuery(urlq);
+
   if (subresname.contains("\"")) {
     // SQLite table name cannot contain double-quote char (itself is used to escape the table name!)
-    qWarning()<<KLF_FUNC_NAME<<"\" character is not allowed in SQLITE database tables (<-> library sub-resources).";
+    qWarning()<<KLF_FUNC_NAME<<"`\"' character is not allowed in SQLITE database tables (<-> library sub-resources).";
     return NULL;
   }
 
@@ -271,7 +283,7 @@ KLFLibDBEngine::KLFLibDBEngine(const QSqlDatabase& db, bool autodisconnect,
   pAutoDisconnectDB = autodisconnect;
 
   // load some read-only properties in memory (these are NOT stored in the DB)
-  KLFPropertizedObject::setProperty(PropAccessShared, accessshared);
+  KLFPropertizedObject::doSetProperty(PropAccessShared, accessshared);
 
   setDatabase(db);
   readResourceProperty(-1); // read all resource properties from DB
@@ -306,6 +318,7 @@ KLFLibDBEngine::~KLFLibDBEngine()
 // private
 bool KLFLibDBEngine::tableExists(const QString& subResource) const
 {
+  // sqlite does not distinguish case
   return pDB.tables().contains(dataTableName(subResource), Qt::CaseInsensitive);
 }
 
@@ -402,7 +415,7 @@ bool KLFLibDBEngine::saveResourceProperty(int propId, const QVariant& value)
       return false;
     }
   }
-  KLFPropertizedObject::setProperty(propId, value);
+  KLFPropertizedObject::doSetProperty(propId, value);
   dbPropertyNotifierInstance(pDB.connectionName())->notifyResourcePropertyChanged(propId);
   // will be emitted by own slot from above call
   //  emit resourcePropertyChanged(propId);
@@ -448,7 +461,7 @@ void KLFLibDBEngine::readResourceProperty(int propId)
     }
     QVariant propvalue = convertVariantFromDBData(q.value(1));
     klfDbg( "Setting property `"<<propname<<"' (id #"<<propId<<") to "<<propvalue<<"" ) ;
-    KLFPropertizedObject::setProperty(propId, propvalue);
+    KLFPropertizedObject::doSetProperty(propId, propvalue);
     emit resourcePropertyChanged(propId);
   }
 }
@@ -1222,7 +1235,9 @@ QVariant KLFLibDBEngine::convertVariantToDBData(const QVariant& value) const
 
   // any other case: convert metatype to QByteArray.
   QByteArray valuedata;
-  { QDataStream stream(&valuedata, QIODevice::WriteOnly);
+  { QBuffer buf(&valuedata);
+    buf.open(QIODevice::WriteOnly);
+    QDataStream stream(&buf);
     stream.setVersion(QDataStream::Qt_4_4);
     stream << value; }
   return encaps(ts, valuedata);
@@ -1301,7 +1316,10 @@ QVariant KLFLibDBEngine::decaps(const QByteArray& data) const
   // OTHERWISE, load from datastream save:
 
   QVariant value;
-  { QDataStream stream(valuedata);
+  { QByteArray vdata = valuedata;
+    QBuffer buf(&vdata);
+    buf.open(QIODevice::ReadOnly);
+    QDataStream stream(&buf);
     stream.setVersion(QDataStream::Qt_4_4);
     stream >> value; }
   return value;
