@@ -19,7 +19,7 @@
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
-/* $Id: klfmain.cpp 990 2017-01-03 08:52:39Z phfaist $ */
+/* $Id$ */
 
 #include <QDebug>
 #include <QString>
@@ -253,24 +253,32 @@ KLF_EXPORT void klf_reload_translations(QCoreApplication *app, const QString& cu
 
 KLF_EXPORT QString klfFindTranslatedDataFile(const QString& baseFileName, const QString& extension)
 {
+  KLF_DEBUG_BLOCK(KLF_FUNC_NAME) ;
+
   QString loc = klfconfig.UI.locale;
   QStringList suffixes;
   suffixes << "_"+loc
 	   << "_"+loc.section('_',0,0)
 	   << "";
-  int k = 0;
-  QString fn;
-  while ( k < suffixes.size() &&
-	  ! QFile::exists(fn = QString("%1%2%3").arg(baseFileName, suffixes[k], extension)) ) {
-    klfDbg( "base="<<baseFileName<<" extn="<<extension<<"; tried fn="<<fn ) ;
-    ++k;
+
+  QStringList basedatadirs = QStringList()
+    << klfconfig.homeConfigDir + "/data/"
+    << klfconfig.globalShareDir + "/data/"
+    << ":/data/";
+
+  foreach (QString suffix, suffixes) {
+    klfDbg("trying suffix=" << suffix) ;
+    foreach (QString basedatadir, basedatadirs) {
+      QString fn = basedatadir + baseFileName + suffix + extension;
+      klfDbg("trying basedatadir=" << basedatadir << ": fn=" << fn) ;
+      if (QFile::exists(fn)) {
+        return fn;
+      }
+    }
   }
-  if (k >= suffixes.size()) {
-    qWarning()<<KLF_FUNC_NAME<<": Can't find good translated file for "<<qPrintable(baseFileName+extension)
-	      <<"! last try was "<<fn;
-    return QString();
-  }
-  return fn;
+
+  klfWarning("Can't find neither translated nor original file for " << baseFileName+extension << " ! ") ;
+  return QString();
 }
 
 
