@@ -55,21 +55,21 @@
 
 #include "qtcolortriangle.h"
 
-#include <QtCore/QEvent>
-#include <QtCore/QMap>
-#include <QtCore/QVarLengthArray>
-#include <QtGui/QConicalGradient>
-#include <QtGui/QFrame>
-#include <QtGui/QImage>
-#include <QtGui/QKeyEvent>
-#include <QtGui/QLayout>
-#include <QtGui/QMouseEvent>
-#include <QtGui/QPainter>
-#include <QtGui/QPainterPath>
-#include <QtGui/QPixmap>
-#include <QtGui/QResizeEvent>
-#include <QtGui/QToolTip>
-#include <QtGui/QVBoxLayout>
+#include <QEvent>
+#include <QMap>
+#include <QVarLengthArray>
+#include <QConicalGradient>
+#include <QFrame>
+#include <QImage>
+#include <QKeyEvent>
+#include <QLayout>
+#include <QMouseEvent>
+#include <QPainter>
+#include <QPainterPath>
+#include <QPixmap>
+#include <QResizeEvent>
+#include <QToolTip>
+#include <QVBoxLayout>
 
 #include <math.h>
 
@@ -539,7 +539,7 @@ void QtColorTriangle::paintEvent(QPaintEvent *e)
 {
     QPainter p(this);
     if (e->rect().intersects(contentsRect()))
-        p.setClipRegion(e->region().intersect(contentsRect()));
+        p.setClipRegion(e->region().intersected(contentsRect()));
     if (mustGenerateBackground) {
 	genBackground();
 	mustGenerateBackground = false;
